@@ -3,7 +3,7 @@ context("stdout and stderr")
 test_that("test output for std_out equals TRUE/FALSE", {
   skip_if_not(packageVersion("base") >= "3.2.2", "skipping capture.output tests")
   is_windows <- identical("windows", tolower(Sys.info()[["sysname"]]))
-  string <- "hello world"
+  string <- "helloworld"
   if(is_windows){
     output1 <- capture.output(res <- exec_wait('cmd', c('/C', 'echo', string)))
     output2 <- capture.output(res <- exec_wait('cmd', c('/C', 'echo', string), std_out = FALSE))
@@ -21,3 +21,15 @@ test_that("test output for std_out equals TRUE/FALSE", {
   expect_equal(sub("\\W+$", "", output3), string)
   expect_equal(output4, character())
 })
+
+test_that("User supplied callback function", {
+  user <- system2("whoami", stdout = TRUE)
+  out <- NULL
+  add <- function(x){
+    out <<- c(out, x)
+  }
+  res <- exec_wait('whoami', std_out = add)
+  expect_equal(res, 0)
+  expect_equal(trimws(rawToChar(out)), user)
+
+})
